Module blaxel.core.sandbox.client.models.process_response_status
================================================================

Classes
-------

`ProcessResponseStatus(*args, **kwds)`
:   str(object='') -> str
    str(bytes_or_buffer[, encoding[, errors]]) -> str
    
    Create a new string object from the given object. If encoding or
    errors is specified, then the object must expose a data buffer
    that will be decoded using the given encoding and error handler.
    Otherwise, returns the result of object.__str__() (if defined)
    or repr(object).
    encoding defaults to 'utf-8'.
    errors defaults to 'strict'.

    ### Ancestors (in MRO)

    * builtins.str
    * enum.Enum

    ### Class variables

    `COMPLETED`
    :   The type of the None singleton.

    `FAILED`
    :   The type of the None singleton.

    `KILLED`
    :   The type of the None singleton.

    `RUNNING`
    :   The type of the None singleton.

    `STOPPED`
    :   The type of the None singleton.